OData Metadata Classes
======================

.. py:module:: pyslet.odata2.metadata

This module defines sub-classes of those defined in the EDM that include
special handling of the OData defined metadata attributes.

EDM Elements
------------

Feed Customisation
~~~~~~~~~~~~~~~~~~

..	autoclass:: EntityType
	:members:
	:show-inheritance:

..	autoclass:: Property
	:members:
	:show-inheritance:

..	autoclass:: FeedCustomisationMixin
	:members:
	:show-inheritance:


Entity Containers
~~~~~~~~~~~~~~~~~

..	autoclass:: EntityContainer
	:members:
	:show-inheritance:

..	autoclass:: EntitySet
	:members:
	:show-inheritance:


EDMX Elements
-------------

..	autoclass:: Document
	:members:
	:show-inheritance:

..	autoclass:: DataServices
	:members:
	:show-inheritance:



